==> smsalert-0.1.1.tar.gz: README.md <==
# SMS Alert Dart package 

A Dart package which helps developers with SMS Alert API services.(https://www.smsalert.co.in)

## Features

* Send SMS programmatically
* Use all SMS Alert API services in your Dart projects
* Send SMS, Schedule SMS, Send bulk SMS to group and many more functions to use


## Getting Started

Check out the Example provided with this package.

To use this package :

- add the dependency to your pubspec.yaml file.

```yaml
dependencies:
  smsalert: ^0.1.1
```

### How to use


#### Create an authenticated SMS Alert instance
```dart
SMSAlert object = new SMSAlert(_user, _pwd); 
```


#### Add your SMS Alert account username and password
```dart
_user ??= 'SMSALERT_ACCOUNT_USERNAME';
_pwd ??= 'SMSALERT_ACCOUNT_PASSWORD';
```

#### Send SMS
```dart
Map message = await object.messages.sendsms({
    'text': 'Hello from Dart!', //SMS text
    'sender': 'CVDEMO', // a valid sender ID
    'mobileno': '+918010551055', // your destination phone number
    'route': 'demo' //to select route
  });
```

#### Schedule SMS
```dart
Map message = await object.messages.schedulesms({
    'text': 'Hello from Dart!', //SMS text
    'sender': 'CVDEMO', // a valid sender ID
    'mobilno': '+918010551055', // your destination phone number
    'schedule': '2021-07-10 12:00:02' //schedule your messages(YYYY-MM-DD HH:MM:SS);
```

#### View SenderID List
```dart
Map senderID = await object.messages.senderlist();//function call
print(senderID);//prints your SenderID list
```

#### View Credits balance
```dart
Map Credits = await object.messages.creditstatus();//function call
print(Credits);//prints your SMS Alert credit balance
```

#### To call any API function

```dart
Map call = await object.messages.callapi(action_name, data);//function call
print(call);//prints the API response
```
##### Where:
  1. action_name = '<API url endpoint>' ; (eg.push,creditstatus,contactlist,etc)
  2. var data = {                    
          'sender': 'CVDEMO',
          'mobileno': '918010551055',  
          'text': 'Hello from Dart!', 
          'route':'demo'
            };

## Useful articles

Check out our comprehensive [API documentation](https://kb.smsalert.co.in/developers-api/) for more information about our API implementation.

## Contact us

You can contact us at <support@cozyvision.com>.


## Author

This SMS Alert Dart package is developed by [SMS Alert](https://smsalert.co.in).

==> smsalert-0.1.2.tar.gz: README.md <==
# SMS Alert Dart package 

A Dart package which helps developers with SMS Alert API services.(https://www.smsalert.co.in)

## Features

* Send SMS programmatically
* Use all SMS Alert API services in your Dart projects
* Send SMS, Schedule SMS, Send bulk SMS to group and many more functions to use


## Getting Started

Check out the Example provided with this package.

To use this package :

- add the dependency to your pubspec.yaml file.

```yaml
dependencies:
  smsalert: ^0.1.1
```

### How to use


#### Create an authenticated SMS Alert instance
```dart
SMSAlert object = new SMSAlert(_user, _pwd); 
```


#### Add your SMS Alert account username and password
```dart
_user ??= 'SMSALERT_ACCOUNT_USERNAME';
_pwd ??= 'SMSALERT_ACCOUNT_PASSWORD';
```

#### Send SMS
```dart
Map message = await object.messages.sendsms({
    'text': 'Hello from Dart!', //SMS text
    'sender': 'CVDEMO', // a valid sender ID
    'mobileno': '+918010551055', // your destination phone number
    'route': 'demo' //to select route
  });
```

#### Schedule SMS
```dart
Map message = await object.messages.schedulesms({
    'text': 'Hello from Dart!', //SMS text
    'sender': 'CVDEMO', // a valid sender ID
    'mobilno': '+918010551055', // your destination phone number
    'schedule': '2021-07-10 12:00:02' //schedule your messages(YYYY-MM-DD HH:MM:SS);
```

#### View SenderID List
```dart
Map senderID = await object.messages.senderlist();//function call
print(senderID);//prints your SenderID list
```

#### View Credits balance
```dart
Map Credits = await object.messages.creditstatus();//function call
print(Credits);//prints your SMS Alert credit balance
```

#### To call any API function

```dart
Map call = await object.messages.callapi(action_name, data);//function call
print(call);//prints the API response
```
##### Where:
  1. action_name = 'API_url_endpoint' ; (eg.push,creditstatus,contactlist,etc)
  2. var data = {                    
          'sender': 'CVDEMO',
          'mobileno': '918010551055',  
          'text': 'Hello from Dart!', 
          'route':'demo'
            };

## Useful articles

Check out our comprehensive [API documentation](https://kb.smsalert.co.in/developers-api/) for more information about our API implementation.

## Contact us

You can contact us at <support@cozyvision.com>.


## Author

This SMS Alert Dart package is developed by [SMS Alert](https://smsalert.co.in).
